==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DesktopMFARecoveryPinOrgSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DesktopMFARecoveryPinOrgSetting
 */
@JsonPropertyOrder({ DesktopMFARecoveryPinOrgSetting.JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DesktopMFARecoveryPinOrgSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED = "desktopMFARecoveryPinEnabled";
    private Boolean desktopMFARecoveryPinEnabled = false;

    public DesktopMFARecoveryPinOrgSetting() {
    }

    public DesktopMFARecoveryPinOrgSetting desktopMFARecoveryPinEnabled(Boolean desktopMFARecoveryPinEnabled) {

        this.desktopMFARecoveryPinEnabled = desktopMFARecoveryPinEnabled;
        return this;
    }

    /**
     * Indicates whether or not the Desktop MFA Recovery PIN feature is enabled
     *
     * @return desktopMFARecoveryPinEnabled
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether or not the Desktop MFA Recovery PIN feature is enabled")
    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getDesktopMFARecoveryPinEnabled() {
        return desktopMFARecoveryPinEnabled;
    }

    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDesktopMFARecoveryPinEnabled(Boolean desktopMFARecoveryPinEnabled) {
        this.desktopMFARecoveryPinEnabled = desktopMFARecoveryPinEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DesktopMFARecoveryPinOrgSetting desktopMFARecoveryPinOrgSetting = (DesktopMFARecoveryPinOrgSetting) o;
        return Objects.equals(this.desktopMFARecoveryPinEnabled,
                desktopMFARecoveryPinOrgSetting.desktopMFARecoveryPinEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(desktopMFARecoveryPinEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DesktopMFARecoveryPinOrgSetting {\n");
        sb.append("    desktopMFARecoveryPinEnabled: ").append(toIndentedString(desktopMFARecoveryPinEnabled))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DesktopMFARecoveryPinOrgSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DesktopMFARecoveryPinOrgSetting
 */
@JsonPropertyOrder({ DesktopMFARecoveryPinOrgSetting.JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DesktopMFARecoveryPinOrgSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED = "desktopMFARecoveryPinEnabled";
    private Boolean desktopMFARecoveryPinEnabled = false;

    public DesktopMFARecoveryPinOrgSetting() {
    }

    public DesktopMFARecoveryPinOrgSetting desktopMFARecoveryPinEnabled(Boolean desktopMFARecoveryPinEnabled) {

        this.desktopMFARecoveryPinEnabled = desktopMFARecoveryPinEnabled;
        return this;
    }

    /**
     * Indicates whether or not the Desktop MFA Recovery PIN feature is enabled
     *
     * @return desktopMFARecoveryPinEnabled
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether or not the Desktop MFA Recovery PIN feature is enabled")
    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getDesktopMFARecoveryPinEnabled() {
        return desktopMFARecoveryPinEnabled;
    }

    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_RECOVERY_PIN_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDesktopMFARecoveryPinEnabled(Boolean desktopMFARecoveryPinEnabled) {
        this.desktopMFARecoveryPinEnabled = desktopMFARecoveryPinEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DesktopMFARecoveryPinOrgSetting desktopMFARecoveryPinOrgSetting = (DesktopMFARecoveryPinOrgSetting) o;
        return Objects.equals(this.desktopMFARecoveryPinEnabled,
                desktopMFARecoveryPinOrgSetting.desktopMFARecoveryPinEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(desktopMFARecoveryPinEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DesktopMFARecoveryPinOrgSetting {\n");
        sb.append("    desktopMFARecoveryPinEnabled: ").append(toIndentedString(desktopMFARecoveryPinEnabled))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
